@@ -20,8 +20,8 @@
  * Globus FTP Client Library
  *
  * $RCSfile: globus_i_ftp_client.h,v $
- * $Revision: 1.50 $
- * $Date: 2011/05/19 04:03:43 $
+ * $Revision: 1.50.10.1 $
+ * $Date: 2012/06/27 14:49:20 $
  */
 
 #ifndef GLOBUS_L_INCLUDE_FTP_CLIENT_H
@@ -314,7 +314,8 @@ typedef enum
     GLOBUS_FTP_CLIENT_MDTM,
     GLOBUS_FTP_CLIENT_SIZE,
     GLOBUS_FTP_CLIENT_CKSM,
-    GLOBUS_FTP_CLIENT_FEAT
+    GLOBUS_FTP_CLIENT_FEAT,
+    GLOBUS_FTP_CLIENT_CWD
 }
 globus_i_ftp_client_operation_t;
 
@@ -407,7 +408,8 @@ typedef enum
     GLOBUS_FTP_CLIENT_TARGET_COMPLETED_OPERATION,
     GLOBUS_FTP_CLIENT_TARGET_NOOP,
     GLOBUS_FTP_CLIENT_TARGET_FAULT,
-    GLOBUS_FTP_CLIENT_TARGET_CLOSED
+    GLOBUS_FTP_CLIENT_TARGET_CLOSED,
+    GLOBUS_FTP_CLIENT_TARGET_SETUP_CWD
 }
 globus_ftp_client_target_state_t;
 
